# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('boxes', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='box',
            name='content_html',
            field=models.TextField(blank=True),
        ),
    ]



from django import template
from django.core.urlresolvers import reverse

from ..forms import BoxForm
from ..models import Box


register = template.Library()


@register.inclusion_tag("pinax/boxes/_box.html", takes_context=True)
def box(context, label, show_edit=True, *args, **kwargs):

    request = context["request"]
    can_edit = request.user.has_perm("boxes.change_box")

    try:
        box = Box.objects.get(label=label)
    except Box.DoesNotExist:
        box = None

    if can_edit and show_edit:
        form = BoxForm(instance=box, prefix=label)
        form_action = reverse("box_edit", args=[label])
    else:
        form = None
        form_action = None

    context.update({
        "label": label,
        "box": box,
        "form": form,
        "form_action": form_action,
    })
    context.update(kwargs)
    return context



"""
@@@ this is temporary until we have solved using AppConfig instead

    tracking: https://github.com/pinax/django-user-accounts/issues/184
"""
import importlib

from django.conf import settings  # noqa
from django.core.exceptions import ImproperlyConfigured

from appconf import AppConf


def load_path_attr(path):
    i = path.rfind(".")
    module, attr = path[:i], path[i + 1:]
    try:
        mod = importlib.import_module(module)
    except ImportError as e:
        raise ImproperlyConfigured(
            "Error importing {0}: '{1}'".format(module, e)
        )
    try:
        attr = getattr(mod, attr)
    except AttributeError:
        raise ImproperlyConfigured(
            "Module '{0}' does not define a '{1}'".format(module, attr)
        )
    return attr


class PinaxBoxesAppConf(AppConf):

    HOOKSET = "pinax.boxes.hooks.DefaultHookSet"

    class Meta:
        prefix = "pinax_boxes"

    def configure_hookset(self, value):
        return load_path_attr(value)()
